Creates a two-dimensional array containing both the Gramian Angular Summation Field (GASF) and the Gramian Angular Difference Field (GADF) produced from a single ONT tail chunk. Using both representations increases the sensitivity of the CNN classification by overcoming the limitations of each method individually.
Value
An array of dimensions (100, 100, 2) where the first channel
contains the GASF and the second channel contains the GADF, both
produced by create_gaf.
See also
create_gaf for individual GAF computation,
create_gaf_list for batch processing,
predict_gaf_classes for downstream CNN classification