Represents time series data (ONT squiggle) in a polar coordinate system instead of the typical Cartesian coordinates. This is a pure-R equivalent of the Python pyts.image implementation.
Value
An array of dimensions (100, 100, 1) with values representing the Gramian Angular Field transformation of the input signal chunk. Values are in the range [0, 1].
Details
Two methods of transformation are available: Gramian Angular Summation Field (GASF) and Gramian Angular Difference Field (GADF).
The transformation proceeds as follows:
Rescale signal values to the interval [-1, 1]
Compute the inverse trigonometric function (
acosfor GASF,asinfor GADF) of each valueForm a pairwise matrix by summing (GASF) or differencing (GADF) the angle vectors
Apply the corresponding trigonometric function (
cosorsin) to the matrixReshape to a 100x100x1 array
Rescale result to the interval [0, 1]
See also
combine_gafs for combining GASF and GADF into a single
array, create_gaf_list for batch GAF computation