Load Keras model for multiclass signal prediction
Source:R/ninetails_misc_helper_functions.R
load_keras_model.RdLoads a pretrained convolutional neural network (CNN) model for classifying Gramian Angular Field representations of poly(A) tail signal chunks into nucleotide categories (A, C, G, U). When called without arguments, the default model bundled with ninetails is loaded. A custom model path can be provided for user-trained models.
See also
predict_gaf_classes where this function is called,
combine_gafs for preparing GAF input arrays