Creates a visual representation of multiple gramian angular fields based on provided gaf_list (plots all gafs from the given list).
Source:R/ninetails_plotting_functions.R
plot_multiple_gaf.RdThe function saves the plots to files with predefined size 100x100 pixels.
Value
multiple png files containing gramian angular fields representing given fragment of nanopore read signal.
Details
A feature useful for creating custom data sets for network training. It is recommended to use this feature with caution. Producing multiple graphs from extensive data sets may cause the system to crash.
This function plots one-channel (100,100,1) as well as multi-channel gafs (e.g. 100,100,2).
IMPORTANT NOTE! In current version, this function plots multi-channel matrices in collapsed manner. If one wants to separate color spaces to GASF/GADF channels or to R,G,B space, this function would not be suitable. The data would require additional processing steps!