Plots qc data (qc_tag) inherited from nanopolish polya function.
Source:R/ninetails_plotting_functions.R
plot_nanopolish_qc.RdProvides insight into the proportion of each quality tag category per sample or experiment condition defined by the user.
Details
This is the ninetails' implementation of the
name function originally written
by P. Krawczyk (smeagol) and incorporated within the NanoTail package.
For original source code, see: https://github.com/LRB-IIMCB/nanotail/blob/master/R/polya_plots.R
The variable names were adjusted according to the naming convention within ninetails to avoid confusion.
Many thanks to the author of original source code for help and advice.