Scatterplot of nonA residue positions within poly(A) tail
Source:R/ninetails_plotting_functions.R
plot_rug_density.RdThis function allows to produce the scatterplot of raw non-A residue predictions (y-axis) along the user-defined tail span (x-axis). The resulting plot also contains the rugs and ridges along the axes, which are a visual aid designed to better show the distributions of given residue.
Arguments
- residue_data
A dataframe or tibble containig non-A residue predictions made by ninetails pipeline.
- base
character. One of the following ["C"/"G","U"]. This parameter defines which nonadenosine is to be plotted. It is obligatory to prevent the overplotting.
- max_length
numeric [1]. This parameter controls maximum length of the poly(A) tail to be taken into consideration for plotting.