Process and split Dorado summary file into smaller parts
Source:R/ninetails_core_functions_dorado_DRS.R
process_dorado_summary.RdSplits a Dorado summary file or data frame (in-memory file) into multiple smaller files for downstream analysis. This helps to avoid memory overflow and data loss during processing.
Arguments
- dorado_summary
Character path to Dorado summary file, or a data frame containing summary information.
- save_dir
Character path to directory where split summary files will be saved.
- part_size
Integer. Number of reads per file part when splitting the summary file.
- cli_log
Function for logging messages and progress.